@@ -81,7 +81,7 @@ on_activatable_extension_added (PeasExtensionSet *set,
 				PeasExtension    *exten,
 				TotemPluginsEngine *engine)
 {
-	peas_extension_call (exten, "activate");
+	peas_activatable_activate (PEAS_ACTIVATABLE (exten));
 }
 
 static void
@@ -90,7 +90,7 @@ on_activatable_extension_removed (PeasExtensionSet *set,
 				  PeasExtension    *exten,
 				  TotemPluginsEngine *engine)
 {
-	peas_extension_call (exten, "deactivate");
+	peas_activatable_deactivate (PEAS_ACTIVATABLE (exten));
 }
 
 TotemPluginsEngine *
@@ -99,6 +99,7 @@ totem_plugins_engine_get_default (TotemObject *totem)
 	static TotemPluginsEngine *engine = NULL;
 	char **paths;
 	guint i;
+	const GList *plugin_infos, *l;
 
 	if (G_LIKELY (engine != NULL))
 		return g_object_ref (engine);
@@ -120,6 +121,8 @@ totem_plugins_engine_get_default (TotemObject *totem)
 	}
 	g_strfreev (paths);
 
+	peas_engine_enable_loader (PEAS_ENGINE (engine), "python");
+
 	g_object_add_weak_pointer (G_OBJECT (engine),
 				   (gpointer) &engine);
 
@@ -137,6 +140,17 @@ totem_plugins_engine_get_default (TotemObject *totem)
 
 	g_settings_bind (engine->priv->settings, "active-plugins", engine, "loaded-plugins", G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_NO_SENSITIVITY);
 
+	/* Load builtin plugins */
+	plugin_infos = peas_engine_get_plugin_list (PEAS_ENGINE (engine));
+
+	for (l = plugin_infos; l != NULL; l = l->next) {
+		PeasPluginInfo *plugin_info = PEAS_PLUGIN_INFO (l->data);
+
+		if (peas_plugin_info_is_builtin (plugin_info)) {
+			peas_engine_load_plugin (PEAS_ENGINE (engine), plugin_info);
+		}
+	}
+
 	return engine;
 }
 
